@@ -12,8 +12,14 @@ class Action(object):
         for key in self.keys:
             if key != "Action" and key != "Variables" and key != "auxiliar_commands":
                 package += "%s: %s\r\n" % (key, self.keys[key])
-        for var in self.variables:
-            package += "Variable: %s=%s\r\n" % (var, self.variables[var])
+        if self.variables:
+            lista_variables = ""
+            separator = ""
+            for var in self.variables:
+                lista_variables += f"{separator}{var}={self.variables[var]}"
+                separator = ","
+            package += f"Variable: {lista_variables}"
+
         return package
 
     def __getattr__(self, item):
