@@ -1,6 +1,6 @@
 from unittest import TestCase
 from uuid import uuid4
-from AsteriskCommand.get_info_anexos import GetInfoAnexos
+from AsteriskCommandApi.get_info_anexos import GetInfoAnexos
 from tests.commands.auxiliar_commands import Auxiliar
 
 
